@@ -240,6 +240,7 @@ struct thread_data {
 	 */
 	uint64_t io_issues[DDIR_RWDIR_CNT];
 	uint64_t io_issue_bytes[DDIR_RWDIR_CNT];
+	uint64_t loops;
 
 	/*
 	 * Completions
@@ -648,6 +649,7 @@ enum {
 	FIO_RAND_DIST_RANDOM	= 0,
 	FIO_RAND_DIST_ZIPF,
 	FIO_RAND_DIST_PARETO,
+	FIO_RAND_DIST_GAUSS,
 };
 
 #define FIO_DEF_ZIPF		1.1
